diff --git a/src/blackgui/components/aircraftcomponent.cpp b/src/blackgui/components/aircraftcomponent.cpp
index d67932053..e75ec0314 100644
--- a/src/blackgui/components/aircraftcomponent.cpp
+++ b/src/blackgui/components/aircraftcomponent.cpp
@@ -31,17 +31,17 @@ namespace BlackGui
this->ui->tvp_AirportsInRange->setResizeMode(CAirportView::ResizingOnce);
m_updateTimer = new CUpdateTimer(SLOT(update()), this);
- connect(this->ui->tvp_AircraftsInRange, &CAircraftView::countChanged, this, &CAircraftComponent::ps_countChanged);
+ connect(this->ui->tvp_AircraftInRange, &CAircraftView::countChanged, this, &CAircraftComponent::ps_countChanged);
connect(this->ui->tvp_AirportsInRange, &CAircraftView::countChanged, this, &CAircraftComponent::ps_countChanged);
}
CAircraftComponent::~CAircraftComponent()
{ }
- int CAircraftComponent::countAircrafts() const
+ int CAircraftComponent::countAircraft() const
{
- Q_ASSERT(this->ui->tvp_AircraftsInRange);
- return this->ui->tvp_AircraftsInRange->rowCount();
+ Q_ASSERT(this->ui->tvp_AircraftInRange);
+ return this->ui->tvp_AircraftInRange->rowCount();
}
int CAircraftComponent::countAirportsInRange() const
@@ -52,16 +52,16 @@ namespace BlackGui
void CAircraftComponent::update()
{
- Q_ASSERT(this->ui->tvp_AircraftsInRange);
+ Q_ASSERT(this->ui->tvp_AircraftInRange);
Q_ASSERT(this->getIContextNetwork());
Q_ASSERT(this->getIContextSimulator());
if (this->getIContextNetwork()->isConnected())
{
- bool visible = (this->isVisibleWidget() && this->currentWidget() == this->ui->tb_AircraftsInRange);
- if (this->countAircrafts() < 1 || visible)
+ bool visible = (this->isVisibleWidget() && this->currentWidget() == this->ui->tb_AircraftInRange);
+ if (this->countAircraft() < 1 || visible)
{
- this->ui->tvp_AircraftsInRange->updateContainer(this->getIContextNetwork()->getAircraftInRange());
+ this->ui->tvp_AircraftInRange->updateContainer(this->getIContextNetwork()->getAircraftInRange());
}
}
if (this->getIContextSimulator()->isConnected())
@@ -94,11 +94,11 @@ namespace BlackGui
void CAircraftComponent::ps_countChanged(int count)
{
Q_UNUSED(count);
- int ac = this->indexOf(this->ui->tb_AircraftsInRange);
+ int ac = this->indexOf(this->ui->tb_AircraftInRange);
int ap = this->indexOf(this->ui->tb_AirportsInRange);
QString acs = this->tabBar()->tabText(ac);
QString aps = this->tabBar()->tabText(ap);
- acs = CGuiUtility::replaceTabCountValue(acs, this->countAircrafts());
+ acs = CGuiUtility::replaceTabCountValue(acs, this->countAircraft());
aps = CGuiUtility::replaceTabCountValue(aps, this->countAirportsInRange());
this->tabBar()->setTabText(ac, acs);
this->tabBar()->setTabText(ap, aps);
diff --git a/src/blackgui/components/aircraftcomponent.ui b/src/blackgui/components/aircraftcomponent.ui
index 99e6e5f93..1b54601f4 100644
--- a/src/blackgui/components/aircraftcomponent.ui
+++ b/src/blackgui/components/aircraftcomponent.ui
@@ -22,9 +22,9 @@
0
-
+
- Aircrafts in range
+ Aircraft in range
@@ -43,7 +43,7 @@
0
-
-
+
false
diff --git a/src/blackgui/components/mainkeypadareacomponent.ui b/src/blackgui/components/mainkeypadareacomponent.ui
index 0d10d519f..f79750576 100644
--- a/src/blackgui/components/mainkeypadareacomponent.ui
+++ b/src/blackgui/components/mainkeypadareacomponent.ui
@@ -194,7 +194,7 @@
- Aircrafts
+ Aircraft
true
diff --git a/src/blackgui/components/aircraftcomponent.h b/src/blackgui/components/aircraftcomponent.h
index 777a706b3..7e5f20baa 100644
--- a/src/blackgui/components/aircraftcomponent.h
+++ b/src/blackgui/components/aircraftcomponent.h
@@ -43,8 +43,8 @@ namespace BlackGui
//! Timer for updating
CUpdateTimer *getTimerComponent() { return this->m_updateTimer; }
- //! Aircrafts in range
- int countAircrafts() const;
+ //! Aircraft in range
+ int countAircraft() const;
//! Airports in range
int countAirportsInRange() const;